@@ -1,11 +1,9 @@
 #undef PACKAGE
 #undef VERSION
-#undef AT_BINDIR
 #undef GETTEXT_PACKAGE
-#undef GDM_CONFIGDIR
-#undef GDM_USER_PATH
 #undef HALT_COMMAND
 #undef REBOOT_COMMAND
+#undef SOUND_PROGRAM
 #undef SUSPEND_COMMAND
 #undef ENABLE_IPV6
 #undef ENABLE_NLS
@@ -38,17 +36,6 @@
 #undef HAVE_XINERAMA
 #undef HAVE_XFREE_XINERAMA
 #undef HAVE_XINPUT
-#undef EXPANDED_AUTHDIR
-#undef EXPANDED_DATADIR
-#undef EXPANDED_BINDIR
-#undef EXPANDED_LIBEXECDIR
-#undef EXPANDED_LIBDIR
-#undef EXPANDED_LOCALEDIR
-#undef EXPANDED_LOGDIR
-#undef EXPANDED_PIXMAPDIR
-#undef EXPANDED_SBINDIR
-#undef EXPANDED_SYSCONFDIR
-#undef EXPANDED_SESSDIR
 #undef X_SERVER
 #undef X_SERVER_PATH
 #undef X_XNEST_PATH
